@@ -9,7 +9,14 @@ def laplace_smoothing(x, n_categories, eps=1e-5):
     return (x + eps) / (x.sum() + n_categories * eps)
 
 class VectorQuantize(nn.Module):
-    def __init__(self, dim, n_embed, decay=0.8, commitment=1., eps=1e-5):
+    def __init__(
+        self,
+        dim,
+        n_embed,
+        decay = 0.8,
+        commitment = 1.,
+        eps = 1e-5
+    ):
         super().__init__()
 
         self.dim = dim
